// This file reproduces all tables and figures of "Does Socially Responsible Investing Change Firm Behavior?" (2023) By Heath, Macciocchi, Michaely, and Ringgenberg

clear all
clear matrix
set type double, perm
set varabbrev off, perm
set seed 1234567
* cd ~/Replication_Package/ *



*---------*
* FIGURES *
*---------*



***FIGURE 1: Growth in SRI Funds and Assets over Time
**Panel A: Number of SRI funds
use Data/funddata, replace
replace mtna = mtna / 1000 // billions
collapse (sum) AUM = mtna (count) nfunds = mtna, by(year ESGfund)
twoway (line nfunds year if ESGfund==1, lwidth(1) lcolor(edkblue)), ///
  graphregion(color(white)) bgcolor(white) ylabel(0 100 200 300 400 500 600) ///
  xtitle("") ytitle("Number of SRI Funds")
graph export Results/Figure1A.pdf, replace
**Panel B: SRI Assets Under Management
twoway (line AUM year if ESGfund==1, lwidth(1) lcolor(edkblue)), ///
  graphregion(color(white)) bgcolor(white) ylabel(0 50 100 150 200 250) ///
  xtitle("") ytitle("Assets Under Management (\$ Billion)")
graph export Results/Figure1B.pdf, replace

*---------------------------------*

***FIGURE 2: Yearly Changes in Firm SRI Outcomes and SRI Fund Investment
**Panel A: Change in EPA Total Emissions
use data/firmpanel, clear
xtset firmid year
gen d1 = f.d.tot_release / 1000000000 // billions
replace d1=100 if d1>100 & d1!=. // (Only for graph presentation)
gen d2 = f.d.overallrating
gen d3 = f.d.diversity
gen d4 = f.d.num_source_reduc_activity
lpoly d1 ESG_frac_held, mcolor(eltblue) msize(tiny) lineopts(lcolor(blue) lwidth(0.6)) xtitle(SRI fund investment (Fraction of Market Cap)) ytitle(Change in Total Emissions (B pounds)) legend(off) title("") note("") graphregion(color(white)) bgcolor(white) bw(.03) ylabel(-100(50)100)
graph export Results/Figure2A.pdf, replace
**Panel B: Change in Pollution Abatements
lpoly d4 ESG_frac_held, mcolor(eltblue) msize(tiny) lineopts(lcolor(blue) lwidth(0.6)) xtitle(SRI fund investment (Fraction of Market Cap)) ytitle(Change in Pollution Abatements) ylabel(-100(50)100) legend(off) title("") note("") graphregion(color(white)) bgcolor(white) bw(0.03)
graph export Results/Figure2B.pdf, replace
**Panel C: Change in Glassdoor Overall Ratings
lpoly d2 ESG_frac_held, mcolor(eltblue) msize(tiny) lineopts(lcolor(blue) lwidth(0.6)) xtitle(SRI fund investment (Fraction of Market Cap)) ytitle(Change in GlassDoor Rating) ylabel(-4(1)4) legend(off) title("") note("") graphregion(color(white)) bgcolor(white) bw(.03)
graph export Results/Figure2C.pdf, replace
**Panel D: Change in Board Gender Diversity
replace ESG_frac_held=0.10 if ESG_frac_held>0.10 & ESG_frac_held!=. // (Only for graph presentation)
lpoly d3 ESG_frac_held, mcolor(eltblue) msize(tiny) lineopts(lcolor(blue) lwidth(0.6)) xtitle(SRI fund investment (Fraction of Market Cap)) ytitle(Change in Board Diversity) ylabel(-1(0.5)1) legend(off) title("") note("") graphregion(color(white)) bgcolor(white) bw(.03)
graph export Results/Figure2D.pdf, replace

*---------------------------------*

***FIGURE 3: Treated vs. control fund lagged returns
**Figure 3-A
use data/matchedfunds, replace
label var logmtna "Log(AUM)"
label var ret3y "3 year adjusted return"
label var ret5y "5 year adjusted return"
label var ret10y "10 year adjusted return"
twoway (histogram ret3y if treated==1, bin(20) fintensity(10) percent bcolor(eltblue)) ///
 (histogram ret3y if treated==0, bin(20) percent fcolor(none) lcolor(black) lpattern(shortdash)) , ///
 legend(order(1 "Treated" 2 "Control" ) position(12)) graphregion(color(white)) bgcolor(white) ytitle(% Observations)
graph export Results/Figure3A.pdf, replace
**Figure 3-B
twoway (histogram ret5y if treated==1, bin(20) fintensity(10) percent bcolor(eltblue)) ///
 (histogram ret5y if treated==0, bin(20) percent fcolor(none) lcolor(black) lpattern(shortdash)) , ///
 legend(order(1 "Treated" 2 "Control" ) position(12)) graphregion(color(white)) bgcolor(white) ytitle(% Observations)
graph export Results/Figure3B.pdf, replace
**Figure 3-C
twoway (histogram ret10y if treated==1, bin(20) fintensity(10) percent bcolor(eltblue)) ///
 (histogram ret10y if treated==0, bin(20) percent fcolor(none) lcolor(black) lpattern(shortdash)) , ///
 legend(order(1 "Treated" 2 "Control" ) position(12)) graphregion(color(white)) bgcolor(white) ytitle(% Observations)
graph export Results/Figure3C.pdf, replace

*---------------------------------*

***FIGURE 4: Treated vs. control fund assets, pre- versus post-treatment
use data/matched_fundpanel, replace
collapse (mean) logassets (sem) se_logassets = logassets, by(treated rel_year)
reshape wide logassets se_logassets, i(rel_year) j(treated)
gen temp = logassets0 if rel_year==0
egen temp2 = max(temp)
replace logassets0 = logassets0 - temp2
drop temp*
gen temp = logassets1 if rel_year==0
egen temp2 = max(temp)
replace logassets1 = logassets1 - temp2
drop temp*
label var logassets1 "Treated Funds"
label var logassets0 "Control Funds"
twoway (line logassets0 rel_year, lwidth(1) lcolor(eltblue) ytitle("Log Assets")) (line logassets1 rel_year, lwidth(1) lcolor(edkblue)) ///
    , xline(0.5, lwidth(0.5) lcolor(black) lpattern(dash)) legend(order(2 1)) ///
		   graphregion(color(white)) bgcolor(white) ///
		   ylabel(-0.2 "-20%" -0.1 "-10%" 0 "0%" 0.10 "10%" 0.20 "20%" 0.10 "10%") xtitle("Year Relative to Treatment")
graph export Results/Figure4.pdf, replace



*--------*
* TABLES *
*--------*



***TABLE I: Summary statistics
use Data/firmpanel, clear
eststo clear
local vars ESG_frac_held ESG_active_held ESG_passive_held tot_release AIR WATER LAND num_source_reduc_activity abatement cc_expo overallrating careeropps seniorleadership worklife culturevalues ceo_review outlook Hospitalized Amputation womenonboard diversity
replace ESG_frac_held = ESG_frac_held * 100
replace ESG_active_held = ESG_active_held * 100
replace ESG_passive_held = ESG_passive_held * 100
replace tot_release = tot_release / 1000000000 // billions
replace AIR = AIR / 1000000000 // billions
replace WATER = WATER / 1000000 // millions
replace LAND = LAND / 1000000 // millions
qui estpost summarize `vars' if ESG_frac_held_std!=., d
esttab using Results/Table1.tex, cells("mean(fmt(2)) sd(fmt(2)) p10(fmt(2)) p50(fmt(2)) p90(fmt(2)) count(fmt(0))") ///
  noobs nonumber label title("Summary statistics") replace

*---------------------------------*
  
***TABLE II: Selection Effects: SRI funds and corporate environmental behavior
use Data/firmpanel, clear
*Column 1 Total releases
reghdfe logrelease_scaled 		ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table2.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes) replace
*Column 2 Air
reghdfe logair_scaled 			ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table2.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 3 Water
reghdfe logwater_scaled 		ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table2.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 4 Land
reghdfe logland_scaled 			ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table2.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 5 Abatement
reghdfe abatement 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table2.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 6 logAbatements
reghdfe log_abate 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table2.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 7 CCExposure
reghdfe cc_expo 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table2.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)

*---------------------------------*

***TABLE III: Selection Effects: SRI funds, employee well-being, and board diversity
use data/firmpanel, clear
**Panel A: Employee well-being
*Column 1 Overall
reghdfe overallrating 			ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes) replace
*Column 2 Careeroppos 
reghdfe careeropps 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 3 Srleader
reghdfe seniorleadership 		ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 4 Worklife
reghdfe worklife 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 5 Culture 
reghdfe culturevalues 			ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 6 CEO 
reghdfe ceo_review 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 7 Outlook 
reghdfe outlook 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
*Column 8 Hospitalizations
reghdfe hospitalized_scaled 	ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes) 
*Column 9 Amputations
reghdfe amputation_scaled 		ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3A.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
**Panel B: Board Diversity
*Column 1 Gender Div.
reghdfe womenonboard 			ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3B.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes) replace
*Column 2 Racial Div.
reghdfe diversity 				ESG_frac_held_std, a(year) cl(firmid)
outreg2 using Results/Table3B.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)

*---------------------------------*

***TABLE IV: Relation between SRI Fund Ownership and Levels and Changes of E&S Output
use Data/firmpanel, clear
gen ESG_held = ESG_frac_held > 0 & ESG_frac_held!=.
*Column 1 Total releases
preserve
drop if tot_release==.
egen lr_quintile = xtile(tot_release), n(5) by(year)
xtset firmid year
gen d_tot_release = d.tot_release
egen d_lr_quintile = xtile(d_tot_release), n(5) by(year)
reghdfe ESG_held lr_quintile d_lr_quintile, a(year) cl(firmid)
outreg2 using Results/Table4, tex(frag) bdec(3) sdec(3) adjr2 addtext(Year FE, Yes) replace 
restore
*Column 2 Abatements
preserve
drop if num_source_reduc_activity==.
egen lr_quintile = xtile(num_source_reduc_activity) if num_source_reduc_activity > 0, n(4) by(year) 
replace lr_quintile = lr_quintile + 1
replace lr_quintile = 1 if num_source_reduc_activity==0
xtset firmid year
gen d_abatement = d.num_source_reduc_activity
egen d_lr_quintile = xtile(d_abatement), n(5) by(year)
reghdfe ESG_held lr_quintile d_lr_quintile, a(year) cl(firmid)
outreg2 using Results/Table4, tex(frag) bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
restore
*Column 3 Gender Div.
preserve
drop if womenonboard==.
egen lr_quintile = xtile(womenonboard), n(5) by(year)
xtset firmid year
gen d_wob = d.womenonboard
egen d_lr_quintile = xtile(d_wob), n(5) by(year)
reghdfe ESG_held lr_quintile d_lr_quintile, a(year) cl(firmid)
outreg2 using Results/Table4, tex(frag) bdec(3) sdec(3) adjr2 addtext(Year FE, Yes) 
restore
*Column 4 Overall
preserve
drop if overallrating==.
egen lr_quintile = xtile(overallrating), n(5) by(year)
xtset firmid year
gen d_overall = d.overallrating
egen d_lr_quintile = xtile(d_overall), n(5) by(year)
reghdfe ESG_held lr_quintile d_lr_quintile, a(year) cl(firmid)
outreg2 using Results/Table4, tex(frag) bdec(3) sdec(3) adjr2 addtext(Year FE, Yes)
restore

*---------------------------------*  

***TABLE V: Difference-in-differences regression of fund assets
use data/matched_fundpanel, clear
gen prepost = (rel_year >0)
reghdfe logassets c.treated##c.prepost, a(panelid rel_year) cl(panelid)
outreg2 using Results/Table5.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Fund x Cohort FE, Yes, Year FE, Yes) replace

*---------------------------------*

***TABLE VI: Treatment effects: SRI funds and corporate environmental behavior
use data/firmpanel, clear
*Column 1 Total releases
reghdfe logrelease_scaled 	fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table6.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes) replace
*Column 2 Air
reghdfe logair_scaled 		fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table6.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 3 Water
reghdfe logwater_scaled 	fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table6.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 4 Land
reghdfe logland_scaled 		fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table6.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 5 Abatement
reghdfe abatement 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table6.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 6 logAbatements
reghdfe log_abate 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table6.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 7 CCExposure
reghdfe cc_expo 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table6.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)

*---------------------------------*

***TABLE VII: Treatment effects: SRI funds, employee well-being, and board diversity
use data/firmpanel, clear
**Panel A: Employee well-being
*Column 1 Overall
reghdfe overallrating 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes) replace
*Column 2 Careeroppos 
reghdfe careeropps 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes) 
*Column 3 Srleader
reghdfe seniorleadership 		fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 4 Worklife
reghdfe worklife 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 5 Culture 
reghdfe culturevalues 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 6 CEO 
reghdfe ceo_review 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 7 Outlook 
reghdfe outlook 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 8 Hospitalization
reghdfe hospitalized_scaled 	fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 9 Amputations
reghdfe amputation_scaled 		fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7A.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
**Panel B: Board Diversity
*Column 1 Gender Div.
reghdfe womenonboard 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7B.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes) replace
*Column 2 Ethnicity Div.
reghdfe diversity 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table7B.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes) 

*---------------------------------*

***TABLE VIII: Heterogeneous Treatment Effects of SRI funds Ownership
use data/firmpanel, clear
*Column 1 Total releases
reghdfe logrelease_scaled fitted_pct_FCI_std fitted_pct_nonFCI_std, a(year firmid) cl(firmid)
outreg2 using Results/Table8.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes) replace
test fitted_pct_FCI_std=fitted_pct_nonFCI_std
*Column 2 logAbatements
reghdfe log_abate fitted_pct_FCI_std fitted_pct_nonFCI_std, a(year firmid) cl(firmid)
outreg2 using Results/Table8.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes)
test fitted_pct_FCI_std=fitted_pct_nonFCI_std
*Column 3 Overall
reghdfe overallrating fitted_pct_FCI_std fitted_pct_nonFCI_std, a(year firmid) cl(firmid)
outreg2 using Results/Table8.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes)
test fitted_pct_FCI_std=fitted_pct_nonFCI_std
*Column 4 Gender Div.
reghdfe womenonboard 		fitted_pct_FCI_std fitted_pct_nonFCI_std, a(year firmid) cl(firmid)
outreg2 using Results/Table8.tex, label nocons bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes) 
test fitted_pct_FCI_std=fitted_pct_nonFCI_std

*---------------------------------*

***TABLE IX: Evidence of Longer-Run Effects
use data/firmpanel, clear
xtset firmid year
*Column 1 Total releases
reghdfe f.logrelease_scaled 	fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes) replace
*Column 2 Total releases
reghdfe f2.logrelease_scaled 	fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 3 logAbatements
reghdfe f.log_abate 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 4 logAbatements
reghdfe f2.log_abate 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 5 Overall
reghdfe f.overallrating 		fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 6 Overall
reghdfe f2.overallrating 		fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)
*Column 7 Gender Div.
reghdfe f.womenonboard 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes) 
*Column 8 Gender Div.
reghdfe f2.womenonboard 		fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table9.tex, label nocons bdec(3) sdec(3) adjr2 stats(coef se ci_high) stnum(replace ci_high=(ci_high-coef)*1.44) addtext(Firm FE, Yes, Year FE, Yes)

*---------------------------------*

***TABLE X: The effects of SRI Investment on E&S Shareholder Proposals
use data/shproposals, replace
*Column 1 Number of ES Items
reghdfe ES_vote 					fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes) replace 
*Column 2 Number of E Items
reghdfe green_vote 					fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes) 
*Column 3 Number of S Items
reghdfe social_vote 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes) 
*Column 4 (**see below**)
*Column 5 Number of ES Items Passed
reghdfe ES_passed 					fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes)  
*Column 6 Fraction of ES Items Passed
reghdfe fraction_ES_passed_total 	fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes)
*
use data/shproposals_SRIfunds, replace
*Column 4 ES Items by SRI Funds
reghdfe SRI_sponsor 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes)
*Column 7 ES Items Withdrawn
reghdfe SRI_withdrawn 				fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes)
*Column 8 Fraction of ES Items Withdrawn
reghdfe frac_SRI_withdrawn 			fitted_pct_ESG_std, a(year firmid) cl(firmid)
outreg2 using Results/Table10, tex(frag) bdec(3) sdec(3) adjr2 addtext(Firm FE, Yes, Year FE, Yes)



***********************************************

*Romano-Wolf, OLS:

*Table II
use data/firmpanel, clear
rename ESG_frac_held_std trt
local depvars "logrelease_scaled logair_scaled logwater_scaled logland_scaled abatement log_abate cc_expo"
set seed 1234567
rwolf_dh_OLS `depvars', indepvar(trt) reps(1000) 
matrix list e(RW)
drop _all
svmat e(RW), names(col)
ren c1 naive_p
ren c2 bs_p
ren c3 RW_p
export excel using "Results/RW_pvalues_Table2", firstrow(variables) replace

*Table III
use data/firmpanel, clear
rename ESG_frac_held_std trt
local depvars "overallrating careeropps seniorleadership worklife culturevalues ceo_review outlook hospitalized_scaled amputation_scaled womenonboard diversity"
set seed 1234567
rwolf_dh_OLS `depvars', indepvar(trt) reps(1000) 
matrix list e(RW)
drop _all
svmat e(RW), names(col)
ren c1 naive_p
ren c2 bs_p
ren c3 RW_p
export excel using "Results/RW_pvalues_Table3", firstrow(variables) replace

*Table A4A
use data/firmpanel, clear
rename ESG_frac_held_std trt
local depvars "ES_Index Env Soc"
set seed 1234567
rwolf_dh_OLS `depvars', indepvar(trt) reps(1000) 
matrix list e(RW)
drop _all
svmat e(RW), names(col)
ren c1 naive_p
ren c2 bs_p
ren c3 RW_p
export excel using "Results/RW_pvalues_TableA4A", firstrow(variables) replace



*Romano-Wolf, diff in diff:
clear all
clear matrix
set type double, perm
set varabbrev off, perm
cd ~/Dropbox/Index_Funds_CSR/

*Table VI
use data/firmpanel, clear
rename fitted_pct_ESG_std trt
local depvars "logrelease_scaled logair_scaled logwater_scaled logland_scaled abatement log_abate cc_expo"
set seed 1234567
rwolf_dh_DiD `depvars', indepvar(trt) reps(1000) 
matrix list e(RW)
drop _all
svmat e(RW), names(col)
ren c1 naive_p
ren c2 bs_p
ren c3 RW_p
export excel using "Results/RW_pvalues_Table6", firstrow(variables) replace

*Table VII
use data/firmpanel, clear
rename fitted_pct_ESG_std trt
local depvars "overallrating careeropps seniorleadership worklife culturevalues ceo_review outlook hospitalized_scaled amputation_scaled womenonboard diversity"
set seed 1234567
rwolf_dh_DiD `depvars', indepvar(trt) reps(1000) 
matrix list e(RW)
drop _all
svmat e(RW), names(col)
ren c1 naive_p
ren c2 bs_p
ren c3 RW_p
export excel using "Results/RW_pvalues_Table7", firstrow(variables) replace


*Table IX:
use data/firmpanel, clear
rename fitted_pct_ESG_std trt
gen f_logrelease = f.logrelease
gen f2_logrelease = f2.logrelease
gen f_logabate = f.log_abate
gen f2_logabate = f2.log_abate
gen f_overall = f.overallrating
gen f2_overall = f2.overallrating
gen f_womenonboard = f.womenonboard
gen f2_womenonboard = f2.womenonboard
local depvars "f_logrelease f2_logrelease f_logabate f2_logabate f_overall f2_overall f_womenonboard f2_womenonboard"
set seed 1234567
rwolf_dh_DiD `depvars', indepvar(trt) reps(1000) 
matrix list e(RW)
drop _all
svmat e(RW), names(col)
ren c1 naive_p
ren c2 bs_p
ren c3 RW_p
export excel using "Results/RW_pvalues_DID_Table9", firstrow(variables) replace

*Table A4B
use data/firmpanel, clear
rename fitted_pct_ESG_std trt
local depvars "ES_Index Env Soc"
set seed 1234567
rwolf_dh_DiD `depvars', indepvar(trt) reps(1000) 
matrix list e(RW)
drop _all
svmat e(RW), names(col)
ren c1 naive_p
ren c2 bs_p
ren c3 RW_p
export excel using "Results/RW_pvalues_TableA4B", firstrow(variables) replace

